@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE FlexibleContexts #-}
 {-# LANGUAGE NoImplicitPrelude #-}
@@ -377,22 +378,22 @@ main = hspec $ do
             failed <- newIORef 0
             tid <- forkIO $ do
                 catchAny
-                    (threadDelay 20000)
+                    (Control.Concurrent.threadDelay 20000)
                     (const $ writeIORef failed 1)
                 writeIORef failed 2
-            threadDelay 10000
-            throwTo tid DummyException
-            threadDelay 50000
+            Control.Concurrent.threadDelay 10000
+            Control.Concurrent.throwTo tid DummyException
+            Control.Concurrent.threadDelay 50000
             didFail <- readIORef failed
             liftIO $ didFail `shouldBe` (0 :: Int)
         it "tryAny" $ do
             failed <- newIORef False
             tid <- forkIO $ do
-                _ <- tryAny $ threadDelay 20000
+                _ <- tryAny $ Control.Concurrent.threadDelay 20000
                 writeIORef failed True
-            threadDelay 10000
-            throwTo tid DummyException
-            threadDelay 50000
+            Control.Concurrent.threadDelay 10000
+            Control.Concurrent.throwTo tid DummyException
+            Control.Concurrent.threadDelay 50000
             didFail <- readIORef failed
             liftIO $ didFail `shouldBe` False
         it "tryAnyDeep" $ do
@@ -414,16 +415,12 @@ data DummyException = DummyException
     deriving (Show, Typeable)
 instance Exception DummyException
 
-instance Arbitrary (Map Int Char) where
-    arbitrary = mapFromList <$> arbitrary
 instance Arbitrary (HashMap Int Char) where
     arbitrary = mapFromList <$> arbitrary
 instance Arbitrary (Vector Int) where
     arbitrary = fromList <$> arbitrary
 instance Arbitrary (UVector Int) where
     arbitrary = fromList <$> arbitrary
-instance Arbitrary (Set Int) where
-    arbitrary = setFromList <$> arbitrary
 instance Arbitrary (HashSet Int) where
     arbitrary = setFromList <$> arbitrary
 instance Arbitrary ByteString where
@@ -434,5 +431,12 @@ instance Arbitrary Text where
     arbitrary = fromList <$> arbitrary
 instance Arbitrary LText where
     arbitrary = fromList <$> arbitrary
+
+#if !MIN_VERSION_QuickCheck(2,8,2)
 instance Arbitrary (Seq Int) where
     arbitrary = fromList <$> arbitrary
+instance Arbitrary (Set Int) where
+    arbitrary = setFromList <$> arbitrary
+instance Arbitrary (Map Int Char) where
+    arbitrary = mapFromList <$> arbitrary
+#endif
